================
ChessTab - About
================


ChessTab lists the games on a database and displays the scores of selected games.


This is ChessTab-2.2.1

python setup.py install will have installed these packages:

- solentware-base-2.1
- chessql-1.1
- chesstab-2.2.1
- pgn-read-1.2
- solentware-grid-1.1
- solentware-misc-1.1
- uci-net-1.1

ChessTab uses features introduced at Python3.4 but declared stable at Python3.6.

Dependencies:

 Python3.6, or later versions when available, must be installed to run ChessTab.

 tkinter, part of Python, must be installed to run ChessTab.  Sometimes this is installed separately.

 tkinter must be using tk8.6.


Licence:

  a copy of the ChessTab licence is at <package folder>/chesstab/about/LICENCE


Contact:

  see <package folder>/chesstab/about/CONTACT

<package folder> is where chesstab is installed, usually site-packages in the Python installation.

